==> web2ldap-0.16.15.tar.gz: web2ldap-0.16.15/pylib/w2lapp/conninfo.py <==
"""
w2lapp.secinfo.py: Display (SSL) connection data

web2ldap - a web-based LDAP Client,
see http://www.web2ldap.de for details

(c) by Michael Stroeder <michael@stroeder.com>

This module is distributed under the terms of the
GPL (GNU GENERAL PUBLIC LICENSE) Version 2
(see http://www.gnu.org/copyleft/gpl.html)

$Id: conninfo.py,v 1.70 2006/10/22 11:09:04 michael Exp $
"""

import time,ldap,ldapsession,w2lapp.cnf,pyweblib.sslenv,w2lapp.core,w2lapp.gui,msgzip, \
       w2lapp.schema.viewer

from w2lapp.core import utf2display

from w2lapp.session import session

##############################################################################
# Connection info
##############################################################################

def w2l_ConnInfo(sid,outf,command,form,ls,dn,env):

  protocol_version = ls.l.get_option(ldap.OPT_PROTOCOL_VERSION)

  conninfo_flushcaches = int(form.getInputValue('conninfo_flushcaches',['0'])[0])
  if conninfo_flushcaches:
    ls.flushCache()

  ldap_managedsait = form.getInputValue('ldap_managedsait',[None])[0]
  ldap_managedit = form.getInputValue('ldap_managedit',[None])[0]
  ldap_subentries = form.getInputValue('ldap_subentries',[None])[0]

  if ldap_managedsait!=None or ldap_managedit!=None or ldap_subentries!=None:
    if protocol_version<ldap.VERSION3:
      raise w2lapp.core.ErrorExit(
        'Control ManageDsaIT (2.16.840.1.113730.3.4.2) not available with LDAPv%d.' % (protocol_version)
      )
    else:
      if ldap_managedsait!=None:
        ls.l.manage_dsa_it(int(ldap_managedsait),critical=1)
      if ldap_managedit!=None:
        ls.l.manage_dit(int(ldap_managedit),critical=1)
      if ldap_subentries!=None:
        ls.l.del_server_control('search_ext',ldapsession.CONTROL_SUBENTRIES)
        ls.l.del_server_control('search_ext',ldapsession.CONTROL_LDUP_SUBENTRIES)
        if ldap_subentries:
          ls.l.add_server_control(
            'search_ext',
            ldap.controls.BooleanControl(ldap_subentries,1,1)
          )
        

  # Set the LDAP connection option for deferencing aliases
  if 'ldap_deref' in form.inputFieldNames:
    ls.l.deref = int(form.field['ldap_deref'].value[0])
  
  context_menu_list = []

  if protocol_version>=ldap.VERSION3:
    context_menu_list.append(
      form.applAnchor('read','Root DSE',sid,[('dn','')])
    )
  context_menu_list.extend(w2lapp.schema.viewer.SchemaContextMenu(sid,form,ls,dn))

  config_dn_list = []

  if ls.rootDSE.has_key('monitorContext'):
    context_menu_list.append(form.applAnchor('read','Monitor',sid,[('dn',ls.rootDSE['monitorContext'][0])]))
  else:
    config_dn_list.append(('CN=MONITOR','Monitor'))

  if ls.rootDSE.has_key('configContext'):
    # OpenLDAP 2.3+
    context_menu_list.append(form.applAnchor('read','Config',sid,[('dn',ls.rootDSE['configContext'][0])]))
  elif ls.rootDSE.has_key('configurationNamingContext'):
    # MS AD
    context_menu_list.append(form.applAnchor('read','AD Configuration',sid,[('dn',ls.rootDSE['configurationNamingContext'][0])]))
  elif ls.rootDSE.has_key('ibm-configurationnamingcontext'):
    # IBM Directory Server
    context_menu_list.append(form.applAnchor('read','IBM DS Configuration',sid,[('dn',ls.rootDSE['ibm-configurationnamingcontext'][0])]))
  else:
    config_dn_list.extend([
      ('CN=CONFIG','Config'),
      ('CN=Configuration','Configuration'),
      ('cn=ldbm','Database'),
    ])

  for config_dn,txt in config_dn_list:
    try:
      entry_exists = ls.existingEntry(config_dn,suppress_referrals=1)
    except ldap.LDAPError:
      pass
    else:
      if entry_exists:
        context_menu_list.append(form.applAnchor('read',txt,sid,[('dn',config_dn)]))

  if ls.rootDSE.has_key('schemaNamingContext'):
    # MS AD schema configuration
    context_menu_list.append(form.applAnchor('read','AD Schema Configuration',sid,[('dn',ls.rootDSE['schemaNamingContext'][0])]))

  w2lapp.gui.TopSection(
    sid,outf,form,ls,dn,
    'Connection Info',
    w2lapp.gui.MainMenu(sid,form,ls,dn),
    context_menu_list=context_menu_list
  )

  uptime = (time.time()-w2lapp.core.startUpTime)/60

  outf.write("""
    <div id="Message" class="Main">
    <h1>Connection Info</h1>
    <p>%s</p>
    """ % (
      form.formHTML('read','Go to entry',sid,'GET',[],extrastr=form.field['dn'].inputHTML()),
    )
  )

  if protocol_version>=ldap.VERSION3:

    # Prepare input fields for LDAPv3 controls

    if not ls.rootDSE.has_key('supportedControl') or \
       ldapsession.CONTROL_MANAGEDSAIT in ls.rootDSE['supportedControl']:
      form.field['ldap_managedsait'].setDefault(str(int(ls.l._get_server_ctrls('__all__').has_key(ldapsession.CONTROL_MANAGEDSAIT))))
      ldap_managedsait_html = form.field['ldap_managedsait'].inputHTML()
    else:
      ldap_managedsait_html = 'not available'

    if not ls.rootDSE.has_key('supportedControl') or \
       ldapsession.CONTROL_MANAGEDIT in ls.rootDSE['supportedControl']:
      form.field['ldap_managedit'].setDefault(str(int(ls.l._get_server_ctrls('__write__').has_key(ldapsession.CONTROL_MANAGEDIT))))
      ldap_managedit_html = form.field['ldap_managedit'].inputHTML()
    else:
      ldap_managedit_html = 'not available'

    if not ls.rootDSE.has_key('supportedControl') or \
       ldapsession.CONTROL_SUBENTRIES in ls.rootDSE['supportedControl'] or \
       ldapsession.CONTROL_LDUP_SUBENTRIES in ls.rootDSE['supportedControl']:
      options=[('',u'off')]
      if not ls.rootDSE.has_key('supportedControl') or \
         ldapsession.CONTROL_SUBENTRIES in ls.rootDSE['supportedControl']:
         options.append((ldapsession.CONTROL_SUBENTRIES,u'RFC 3672'))
      if not ls.rootDSE.has_key('supportedControl') or \
	 ldapsession.CONTROL_LDUP_SUBENTRIES in ls.rootDSE['supportedControl']:
        options.append((ldapsession.CONTROL_LDUP_SUBENTRIES,u'draft-ietf-ldup-subentry'))
      form.field['ldap_subentries'].setOptions(options)
      form.field['ldap_subentries'].setDefault(
	ldapsession.CONTROL_SUBENTRIES*ls.l._get_server_ctrls('search_ext').has_key(ldapsession.CONTROL_SUBENTRIES) or 
	ldapsession.CONTROL_LDUP_SUBENTRIES*ls.l._get_server_ctrls('search_ext').has_key(ldapsession.CONTROL_LDUP_SUBENTRIES)
      )
      ldap_subentries_html = form.field['ldap_subentries'].inputHTML()
    else:
      ldap_subentries_html = 'not available'

  else:
    ldap_managedsait_html = 'not available with LDAPv2'
    ldap_managedit_html = 'not available with LDAPv2'
    ldap_subentries_html = 'not available with LDAPv2'

  if ls.who:
    who_html = ' | '.join([
        w2lapp.gui.DisplayDN(sid,form,ls,ls.who,commandbutton=0),
        form.applAnchor('read','Read',sid,[('dn',ls.who)]),
        form.applAnchor('passwd','Password',sid,[('dn',ls.who),('passwd_who',ls.who)]),
      ])
  else:
    who_html = 'anonymous'

  derefAliasesStr = str(ls.l.get_option(ldap.OPT_DEREF))
  derefAliasesMenuList = []
  for option_value,option_text in form.field['ldap_deref'].options:
    if option_value!=derefAliasesStr:
      derefAliasesMenuList.append(
        form.applAnchor(
          'conninfo',option_text.encode(form.accept_charset),sid,
          [('dn',dn),('ldap_deref',option_value)]
        )
      )

  outf.write("""
    <h2>LDAP connection</h2>
    <table summary="LDAP connection">
      <tr>
        <td>LDAPv%d connection to:</td>
        <td>%s (%s, %s)</td>
      </tr>
      <tr>
        <td>Server vendor info:</td>
        <td>Vendor: %s / Version: %s</td>
      </tr>
      <tr>
        <td>Bound as:</td>
        <td>%s</td>
      </tr>
    </table>
    """ % (
      protocol_version,
      ls.uri.encode('ascii'),
      ls.charset.upper(),
      {0:'not secured',1:'secured'}[ls.secureConn>0],
      utf2display(form.accept_charset,(ls.rootDSE.get('vendorName',None) or ['unknown'])[0]),
      utf2display(form.accept_charset,(ls.rootDSE.get('vendorVersion',None) or ['unknown'])[0]),
      who_html
    )
  )

  outf.write("""
    <h3>LDAP cache information</h3>
    <p>%s</p>
    <table id="ConnInfoTable" summary="LDAP cache information">
      <tr>
        <td>Cached entries:</td>
        <td>%d</td>
      </tr>
      <tr>
        <td>Cached subschema DN mappings:</td>
        <td>%d</td>
      </tr>
      <tr>
        <td>Cached subschema subentries:</td>
        <td>%d</td>
      </tr>
    </table>
    """ % (
      form.applAnchor(
        'conninfo','Flush all caches',sid,
        [
          ('dn',dn),
          ('conninfo_flushcaches','1'),
        ],
        title='Flush all cached information for this LDAP connection'
      ),     
      len(ls.read_cache),
      len(ls.schema_dn_cache),
      len(ls.schema_cache),
    )
  )
  outf.write("""
    <h3>LDAP options</h3>
    %s
      <input type="hidden" name="dn" value="%s">
      <fieldset title="LDAP options">
        <legend>LDAP options</legend>
        <table id="ConnInfoTable" summary="LDAP options">
          <tr>
            <td>Manage DSA IT:</td>
            <td>%s</td>
            <td>Subentries control:</td>
            <td>%s</td>
          </tr>
          <tr>
            <td>Relax Rules:</td>
            <td>%s</td>
            <td>Alias dereferencing:</td>
            <td>%s</td>
          </tr>
        </table>
        <input type="submit" value="Change options">
      </fieldset>
    </form>
  """ % (
    form.beginFormHTML('conninfo',sid,'GET'),
    utf2display(form.accept_charset,dn),
    ldap_managedsait_html.encode('ascii'),
    ldap_subentries_html.encode('ascii'),
    ldap_managedit_html.encode('ascii'),
    form.field['ldap_deref'].inputHTML(default=str(ls.l.deref))
  ))

  if isinstance(outf,msgzip.GzipFile):
    compresslevel = outf.compresslevel
  else:
    compresslevel = None
  outf.write("""
    <h2>HTTP connection</h2>
    <table summary="HTTP connection">
      <tr><td>Your IP address:</td><td>%s</td></tr>
      <tr><td>Server signature:</td><td>%s</td></tr>
      <tr><td>Character set/encoding:</td><td>%s</td></tr>
      <tr><td>GZIP compression level:</td><td>%s</td></tr>
      <tr><td>Cross-check vars in use:</td><td>%s</td></tr>
    </table>
    <h2>SSL</h2>
    """ % (
      w2lapp.core.guessClientAddr(env),
      form.env.get('SERVER_SIGNATURE',''),
      form.accept_charset.upper(),
      str(compresslevel),
      ', '.join(session.sessiondict['__session_checkvars__'+sid].keys()),
    )
  )
  ssl_valid_dn = w2lapp.cnf.GetParam(ls,'ssl_valid_dn','')
  ssl_valid_idn = w2lapp.cnf.GetParam(ls,'ssl_valid_idn','')
  pyweblib.sslenv.PrintSecInfo(env,w2lapp.cnf.misc.sec_sslacceptedciphers,ssl_valid_dn,ssl_valid_idn,outf)
  outf.write('</div>')
  w2lapp.gui.PrintFooter(outf,form)

==> web2ldap-0.16.22.tar.gz: web2ldap-0.16.22/pylib/w2lapp/conninfo.py <==
"""
w2lapp.secinfo.py: Display (SSL) connection data

web2ldap - a web-based LDAP Client,
see http://www.web2ldap.de for details

(c) by Michael Stroeder <michael@stroeder.com>

This module is distributed under the terms of the
GPL (GNU GENERAL PUBLIC LICENSE) Version 2
(see http://www.gnu.org/copyleft/gpl.html)

$Id: conninfo.py,v 1.76 2007/11/16 11:40:07 michael Exp $
"""

import time,ldap,ldapsession,w2lapp.cnf,pyweblib.sslenv,w2lapp.core,w2lapp.gui,msgzip, \
       w2lapp.schema.viewer

from w2lapp.core import utf2display

from w2lapp.session import session

##############################################################################
# Connection info
##############################################################################

def w2l_ConnInfo(sid,outf,command,form,ls,dn,env):

  protocol_version = ls.l.get_option(ldap.OPT_PROTOCOL_VERSION)

  conninfo_flushcaches = int(form.getInputValue('conninfo_flushcaches',['0'])[0])
  if conninfo_flushcaches:
    ls.flushCache()

  ldap_managedsait = form.getInputValue('ldap_managedsait',[None])[0]
  ldap_relaxrules = form.getInputValue('ldap_relaxrules',[None])[0]
  ldap_subentries = form.getInputValue('ldap_subentries',[None])[0]

  if ldap_managedsait!=None or ldap_relaxrules!=None or ldap_subentries!=None:
    if protocol_version<ldap.VERSION3:
      raise w2lapp.core.ErrorExit(
        'Extended controls not available with LDAPv%d.' % (protocol_version)
      )
    else:
      if ldap_managedsait!=None:
        ls.l.manage_dsa_it(int(ldap_managedsait),critical=1)
      if ldap_relaxrules!=None:
        ls.l.manage_dit(int(ldap_relaxrules),critical=1)
      if ldap_subentries!=None:
        ls.l.del_server_control('search_ext',ldapsession.CONTROL_SUBENTRIES)
        ls.l.del_server_control('search_ext',ldapsession.CONTROL_LDUP_SUBENTRIES)
        if ldap_subentries:
          ls.l.add_server_control(
            'search_ext',
            ldap.controls.BooleanControl(ldap_subentries,1,1)
          )
        

  # Set the LDAP connection option for deferencing aliases
  if 'ldap_deref' in form.inputFieldNames:
    ls.l.deref = int(form.field['ldap_deref'].value[0])
  
  context_menu_list = []

  if protocol_version>=ldap.VERSION3:
    context_menu_list.append(
      form.applAnchor('read','Root DSE',sid,[('dn','')])
    )
  context_menu_list.extend(w2lapp.schema.viewer.SchemaContextMenu(sid,form,ls,dn))

  # List of candidate DNs for probing configuration information
  config_dn_list = []

  monitored_info = None
  if ls.rootDSE.has_key('monitorContext'):
    context_menu_list.append(form.applAnchor('read','Monitor',sid,[('dn',ls.rootDSE['monitorContext'][0])]))
    try:
      monitored_info = ls.readEntry(ls.rootDSE['monitorContext'][0],['monitoredInfo'])[0][1]['monitoredInfo']
    except ldap.LDAPError,KeyError:
      pass
  else:
    config_dn_list.append(('CN=MONITOR','Monitor'))

  if ls.rootDSE.has_key('configContext'):
    # OpenLDAP 2.3+
    context_menu_list.append(form.applAnchor('read','Config',sid,[('dn',ls.rootDSE['configContext'][0])]))
  elif ls.rootDSE.has_key('configurationNamingContext'):
    # MS AD
    context_menu_list.append(form.applAnchor('read','AD Configuration',sid,[('dn',ls.rootDSE['configurationNamingContext'][0])]))
  elif ls.rootDSE.has_key('ibm-configurationnamingcontext'):
    # IBM Directory Server
    context_menu_list.append(form.applAnchor('read','IBM DS Configuration',sid,[('dn',ls.rootDSE['ibm-configurationnamingcontext'][0])]))
  else:
    config_dn_list.extend([
      ('CN=CONFIG','Config'),
      ('CN=Configuration','Configuration'),
      ('cn=ldbm','Database'),
    ])

  if ls.rootDSE.has_key('auditContext'):
    context_menu_list.append(form.applAnchor('read','Audit DB',sid,[('dn',ls.rootDSE['auditContext'][0])]))

  for config_dn,txt in config_dn_list:
    try:
      entry_exists = ls.existingEntry(config_dn,suppress_referrals=1)
    except ldap.LDAPError:
      pass
    else:
      if entry_exists:
        context_menu_list.append(form.applAnchor('read',txt,sid,[('dn',config_dn)]))

  if ls.rootDSE.has_key('schemaNamingContext'):
    # MS AD schema configuration
    context_menu_list.append(form.applAnchor('read','AD Schema Configuration',sid,[('dn',ls.rootDSE['schemaNamingContext'][0])]))

  w2lapp.gui.TopSection(
    sid,outf,form,ls,dn,
    'Connection Info',
    w2lapp.gui.MainMenu(sid,form,ls,dn),
    context_menu_list=context_menu_list
  )

  outf.write("""
    <div id="Message" class="Main">
    <h1>Connection Info</h1>
    <p>%s</p>
    """ % (
      form.formHTML('read','Go to entry',sid,'GET',[],extrastr=form.field['dn'].inputHTML()),
    )
  )

  if protocol_version>=ldap.VERSION3:

    # Prepare input fields for LDAPv3 controls

    if not ls.rootDSE.has_key('supportedControl') or \
       ldapsession.CONTROL_MANAGEDSAIT in ls.rootDSE['supportedControl']:
      form.field['ldap_managedsait'].setDefault(str(int(ls.l._get_server_ctrls('__all__').has_key(ldapsession.CONTROL_MANAGEDSAIT))))
      ldap_managedsait_html = form.field['ldap_managedsait'].inputHTML()
    else:
      ldap_managedsait_html = 'not available'

    if not ls.rootDSE.has_key('supportedControl') or \
       ldapsession.CONTROL_RELAXRULES in ls.rootDSE['supportedControl']:
      form.field['ldap_relaxrules'].setDefault(str(int(ls.l._get_server_ctrls('__write__').has_key(ldapsession.CONTROL_RELAXRULES))))
      ldap_relaxrules_html = form.field['ldap_relaxrules'].inputHTML()
    else:
      ldap_relaxrules_html = 'not available'

    if not ls.rootDSE.has_key('supportedControl') or \
       ldapsession.CONTROL_SUBENTRIES in ls.rootDSE['supportedControl'] or \
       ldapsession.CONTROL_LDUP_SUBENTRIES in ls.rootDSE['supportedControl']:
      options=[('',u'off')]
      if not ls.rootDSE.has_key('supportedControl') or \
         ldapsession.CONTROL_SUBENTRIES in ls.rootDSE['supportedControl']:
         options.append((ldapsession.CONTROL_SUBENTRIES,u'RFC 3672'))
      if not ls.rootDSE.has_key('supportedControl') or \
	 ldapsession.CONTROL_LDUP_SUBENTRIES in ls.rootDSE['supportedControl']:
        options.append((ldapsession.CONTROL_LDUP_SUBENTRIES,u'draft-ietf-ldup-subentry'))
      form.field['ldap_subentries'].setOptions(options)
      form.field['ldap_subentries'].setDefault(
	ldapsession.CONTROL_SUBENTRIES*ls.l._get_server_ctrls('search_ext').has_key(ldapsession.CONTROL_SUBENTRIES) or 
	ldapsession.CONTROL_LDUP_SUBENTRIES*ls.l._get_server_ctrls('search_ext').has_key(ldapsession.CONTROL_LDUP_SUBENTRIES)
      )
      ldap_subentries_html = form.field['ldap_subentries'].inputHTML()
    else:
      ldap_subentries_html = 'not available'

    if not ls.rootDSE.has_key('supportedControl') or \
       ldapsession.CONTROL_SERVERADMINISTRATION in ls.rootDSE['supportedControl']:
      form.field['ldap_serveradministration'].setDefault(str(int(ls.l._get_server_ctrls('__write__').has_key(ldapsession.CONTROL_MANAGEDSAIT))))
      ldap_serveradministration_html = form.field['ldap_serveradministration'].inputHTML()
    else:
      ldap_serveradministration_html = 'not available'

    if not ls.rootDSE.has_key('supportedControl') or \
       ldapsession.CONTROL_DONTUSECOPY in ls.rootDSE['supportedControl']:
      form.field['ldap_dontusecopy'].setDefault(str(int(ls.l._get_server_ctrls('__read__').has_key(ldapsession.CONTROL_DONTUSECOPY))))
      ldap_dontusecopy_html = form.field['ldap_dontusecopy'].inputHTML()
    else:
      ldap_dontusecopy_html = 'not available'

    if not ls.rootDSE.has_key('supportedControl') or \
       ldapsession.CONTROL_DONOTREPLICATE in ls.rootDSE['supportedControl']:
      form.field['ldap_donotreplicate'].setDefault(str(int(ls.l._get_server_ctrls('__write__').has_key(ldapsession.CONTROL_MANAGEDSAIT))))
      ldap_donotreplicate_html = form.field['ldap_donotreplicate'].inputHTML()
    else:
      ldap_donotreplicate_html = 'not available'

  else:
    ldap_managedsait_html = 'not available with LDAPv2'
    ldap_relaxrules_html = 'not available with LDAPv2'
    ldap_subentries_html = 'not available with LDAPv2'
    ldap_dontusecopy_html = 'not available with LDAPv2'
    ldap_serveradministration_html = 'not available with LDAPv2'
    ldap_donotreplicate_html = 'not available with LDAPv2'

  if ls.who:
    who_html = ' | '.join([
        w2lapp.gui.DisplayDN(sid,form,ls,ls.who,commandbutton=0),
        form.applAnchor('read','Read',sid,[('dn',ls.who)]),
        form.applAnchor('passwd','Password',sid,[('dn',ls.who),('passwd_who',ls.who)]),
      ])
  else:
    who_html = 'anonymous'

  derefAliasesStr = str(ls.l.get_option(ldap.OPT_DEREF))
  derefAliasesMenuList = []
  for option_value,option_text in form.field['ldap_deref'].options:
    if option_value!=derefAliasesStr:
      derefAliasesMenuList.append(
        form.applAnchor(
          'conninfo',option_text.encode(form.accept_charset),sid,
          [('dn',dn),('ldap_deref',option_value)]
        )
      )

  outf.write("""
    <h2>LDAP connection</h2>
    <table summary="LDAP connection">
      <tr>
        <td>LDAPv%d connection to:</td>
        <td>%s (%s, %s)</td>
      </tr>
      <tr>
        <td>Server vendor info:</td>
        <td>%s %s</td>
      </tr>
      <tr>
        <td>Bound as:</td>
        <td>%s</td>
      </tr>
    </table>
    """ % (
      protocol_version,
      ls.uri.encode('ascii'),
      ls.charset.upper(),
      {0:'not secured',1:'secured'}[ls.secureConn>0],
      utf2display(form.accept_charset,(ls.rootDSE.get('vendorName',None) or monitored_info or ['unknown'])[0]),
      utf2display(form.accept_charset,(ls.rootDSE.get('vendorVersion',None) or [''])[0]),
      who_html
    )
  )

  outf.write("""
    <h3>LDAP cache information</h3>
    <p>%s</p>
    <table id="ConnInfoTable" summary="LDAP cache information">
      <tr>
        <td>Cached entries:</td>
        <td>%d</td>
      </tr>
      <tr>
        <td>Cached subschema DN mappings:</td>
        <td>%d</td>
      </tr>
      <tr>
        <td>Cached subschema subentries:</td>
        <td>%d</td>
      </tr>
    </table>
    """ % (
      form.applAnchor(
        'conninfo','Flush all caches',sid,
        [
          ('dn',dn),
          ('conninfo_flushcaches','1'),
        ],
        title='Flush all cached information for this LDAP connection'
      ),     
      len(ls.read_cache),
      len(ls.schema_dn_cache),
      len(ls.schema_cache),
    )
  )
  outf.write("""
    <h3>LDAP options</h3>
    %s
      <input type="hidden" name="dn" value="%s">
      <fieldset title="LDAP options">
        <legend>LDAP options</legend>
        <table id="ConnInfoTable" summary="LDAP options">
          <tr>
            <td>Manage DSA IT:</td>
            <td>%s</td>
            <td>Subentries control:</td>
            <td>%s</td>
          </tr>
          <tr>
            <td>Relax Rules:</td>
            <td>%s</td>
            <td>Alias dereferencing:</td>
            <td>%s</td>
          </tr>
          <tr>
            <td>Do not use copy:</td>
            <td>%s</td>
          </tr>
          <tr text="IBM-specific controls">
            <td>Server administration:</td>
            <td>%s</td>
            <td>Do not replicate:</td>
            <td>%s</td>
          </tr>
        </table>
        <input type="submit" value="Change options">
      </fieldset>
    </form>
  """ % (
    form.beginFormHTML('conninfo',sid,'GET'),
    utf2display(form.accept_charset,dn),
    ldap_managedsait_html.encode('ascii'),
    ldap_subentries_html.encode('ascii'),
    ldap_relaxrules_html.encode('ascii'),
    form.field['ldap_deref'].inputHTML(default=str(ls.l.deref)),
    ldap_dontusecopy_html.encode('ascii'),
    ldap_serveradministration_html.encode('ascii'),
    ldap_donotreplicate_html.encode('ascii'),
  ))

  if isinstance(outf,msgzip.GzipFile):
    compresslevel = outf.compresslevel
  else:
    compresslevel = None
  outf.write("""
    <h2>HTTP connection</h2>
    <table summary="HTTP connection">
      <tr><td>Your IP address:</td><td>%s</td></tr>
      <tr><td>Server signature:</td><td>%s</td></tr>
      <tr><td>Character set/encoding:</td><td>%s</td></tr>
      <tr><td>GZIP compression level:</td><td>%s</td></tr>
      <tr><td>Cross-check vars in use:</td><td>%s</td></tr>
    </table>
    <h2>SSL</h2>
    """ % (
      w2lapp.core.guessClientAddr(env),
      form.env.get('SERVER_SIGNATURE',''),
      form.accept_charset.upper(),
      str(compresslevel),
      ', '.join(session.sessiondict['__session_checkvars__'+sid].keys()),
    )
  )
  ssl_valid_dn = w2lapp.cnf.GetParam(ls,'ssl_valid_dn','')
  ssl_valid_idn = w2lapp.cnf.GetParam(ls,'ssl_valid_idn','')
  pyweblib.sslenv.PrintSecInfo(env,w2lapp.cnf.misc.sec_sslacceptedciphers,ssl_valid_dn,ssl_valid_idn,outf)
  outf.write('</div>')
  w2lapp.gui.PrintFooter(outf,form)
